<?php
/** 
*
* search_ignore_words [Argentinian Spanish]
*
* @package language
* @version $Id: $
* @copyright (c) 2007 phpBB Group. Modified by nextgen for phpbbargentina.com in 2012 
* @author 2007-11-26 - Traducido por Huan Manwe junto con phpbb-es.com (http://www.phpbb-es.com) basado en la version argentina hecha por larveando.com.ar ).
* @author - ImagePack made nextgen (Styles Team Leader of http://www.phpbbargentina.com)
* @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html GNU General Public License 
*
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

$words = array(
	'un',
	'acerca',
	'después',
	'hace',
	'todo',
	'casi',
	'largo',
	'montón',
	'también',
	'soy',
	'un',
	'y',
	'respuesta',
	'cualquier',
	'cualquiera',
	'cualesquiera',
	'lugar',
	'son',
	'no son',
	'alrededor',
	'como',
	'preguntar',
	'preguntado',
	'en',
	'mal',
	'ser',
	'porque',
	'sido',
	'antes',
	'siendo',
	'mejor',
	'mejores',
	'entre',
	'grande',
	'por las dudas',
	'pero',
	'por',
	'puede',
	'no puede',
	'venir',
	'podría',
	'no podría',
	'día',
	'días',
	'hizo',
	'no hizo',
	'hacer',
	'hace',
	'no hace',
	'no',
	'bajo',
	'cada',
	'etc',
	'alterno',
	'sino',
	'aun',
	'nunca',
	'cada',
	'cada uno',
	'cada cual',
	'todos',
	'lejos',
	'encontrar',
	'para',
	'encontrado',
	'de',
	'obtener',
	'ir',
	'yendo',
	'ido',
	'bueno',
	'tener',
	'tenido',
	'tuve',
	'he tenido',
	'tengo',
	'no tengo',
	'teniendo',
	'su',
	'acá',
	'sus',
	'hogar',
	'cómo',
	'cuándo',
	'href',
	'yo',
	'si',
	'ini',
	'dentro',
	'es',
	'no es',
	'esto',
	'sólo',
	'saber',
	'gran',
	'menos',
	'como',
	'parecido',
	'pequeño',
	'mirando',
	'mirar',
	'mirado',
	'mirando',
	'mucho',
	'tal vez',
	'muchos',
	'mi',
	'más',
	'mayor',
	'demasiado',
	'debe',
	'no debe',
	'mío',
	'cerca',
	'necesito',
	'nunca',
	'nuevo',
	'noticias',
	'no',
	'ninguno',
	'nada',
	'ahora',
	'fuera',
	'a menudo',
	'viejo',
	'sobre',
	'una vez',
	'solamente',
	'oops',
	'o',
	'otro',
	'nuestro',
	'nuestros',
	'afuera',
	'sobre',
	'página',
	'por favor',
	'poner',
	'pregunta',
	'preguntas',
	'preguntado',
	'cita',
	'preferir',
	'realmente',
	'reciente',
	'dijo',
	'vio',
	'dicho',
	'ella',
	'ver',
	'debería',
	'sitios',
	'chico',
	'así',
	'algún',
	'algo',
	'a veces',
	'acullá',
	'pronto',
	'tomar',
	'que',
	'verdad',
	'gracias',
	'el',
	'allí',
	'ellos',
	'luego',
	'entonces',
	'esos',
	'estos',
	'aquellos',
	'pienso',
	'través',
	'fecha',
	'fechas',
	'para',
	'demasía',
	'bajo',
	'hasta',
	'incierto',
	'arriba',
	'hasta',
	'use',
	'usuarios',
	'versión',
	'muy',
	'vía',
	'querer',
	'fue',
	'camino',
	'nosotros',
	'bien',
	'fueron',
	'fuimos',
	'no fuimos',
	'cuando',
	'dónde',
	'cual',
	'quién',
	'quienes',
	'porque',
	'ancho',
	'con',
	'sin',
	'palabra',
	'malo',
	'peor',
	'podría',
	'escrito',
	'www',
	'yes',
	'ya',
	'tu',
	'tú',
	'tus',
	'AFAIK',
	'IIRC',
	'LOL',
	'ROTF',
	'ROTFLMAO',
	'YMMV',
);

?>